import { Redirect, SplashScreen, Tabs } from 'expo-router';
import React, { useCallback, useEffect } from 'react';
import {
  Feed as FeedIcon,
  Settings as SettingsIcon,
  Style as StyleIcon,
} from '@/components/ui/icons';
import { useAuth, useIsFirstTime } from '@/lib';
import BottomNavigation from '@/library/bottom-navigation';
import {
  DocumentOff,
  DocumentOn,
  HomeOff,
  HomeOn,
  MyPageOff,
  MyPageOn,
} from '@/components/ui/testicons';

export default function TabLayout() {
  const status = useAuth.use.status();
  const [isFirstTime] = useIsFirstTime();

  const hideSplash = useCallback(async () => {
    await SplashScreen.hideAsync();
  }, []);

  useEffect(() => {
    if (status !== 'idle') {
      setTimeout(() => {
        hideSplash();
      }, 1000);
    }
  }, [hideSplash, status]);

  const navigationIcons = {
    index: {
      active: <HomeOn />,
      inactive: <HomeOff />,
    },
    temp: {
      active: <HomeOn />,
      inactive: <HomeOff />,
    },
    paper: {
      active: <HomeOn />,
      inactive: <HomeOff />,
    },
    style: {
      active: <DocumentOn />,
      inactive: <DocumentOff />,
    },
    settings: {
      active: <MyPageOn />,
      inactive: <MyPageOff />,
    },
  };

  if (isFirstTime) {
    return <Redirect href="/onboarding" />;
  }
  if (status === 'signOut') {
    return <Redirect href="/login" />;
  }

  return (
    <Tabs
      screenOptions={{
        headerShown: false,
      }}
      tabBar={(props) => (
        <BottomNavigation {...props} icons={navigationIcons} divider />
      )}
    />
  );
}
